@@ -917,10 +917,10 @@ class Patient(skrt.core.PathData):
 
                 if "image" == dstring:
                     # For "image" modality, group DicomFile objects
-                    # by series instance.
+                    # by series instance uid.
                     matched_attributes = dcm.get_matched_attributes(
                             dtypes[dcm.modality],
-                            "series_instance_uid"
+                            ["series_instance_uid"]
                             )
                     if matched_attributes:
                         matched_attributes[0].dicom_paths.append(dcm.path)
@@ -948,7 +948,8 @@ class Patient(skrt.core.PathData):
                         if "image" == dstring:
                             # Transfer list of source files
                             # from DicomFile object to Image object.
-                            obj.dicom_paths = list(dcm.dicom_paths)
+                            obj.dicom_paths = sorted(list(dcm.dicom_paths),
+                                    key=skrt.core.alphanumeric)
                             # Subsitute Image object for DicomFile object
                             # in dictionary of image types.
                             dtypes[modality][idx] = obj
@@ -1322,6 +1323,8 @@ class Patient(skrt.core.PathData):
         info['plan_prescription_description'] = None
         info['plan_fraction'] = None
         info['plan_target_dose'] = None
+        info['plan_targets'] = None
+        info['plan_organs_at_risk'] = None
         for study in self.studies:
             if hasattr(study, 'plan_types') and study.plan_types:
                 plan_type = sorted(list(study.plan_types.keys()))[0]
@@ -1333,6 +1336,10 @@ class Patient(skrt.core.PathData):
                         plan.prescription_description)
                 info['plan_fraction'] = plan.n_fraction
                 info['plan_target_dose'] = plan.target_dose
+                if skrt.core.is_list(plan.targets):
+                    info['plan_targets'] = len(plan.targets)
+                if skrt.core.is_list(plan.organs_at_risk):
+                    info['plan_organs_at_risk'] = len(plan.organs_at_risk)
                 break
 
         # Store information about all data types, across all studies.
@@ -1374,17 +1381,27 @@ class Patient(skrt.core.PathData):
                             info[file_label] += obj.get_n_file()
                             info[size_label] += obj.get_file_size()
 
-        # Create lists of image objects for planning and for treatment.
+        # Create lists of Image objects for planning and for treatment,
+        # and list of StructureSet objects for planning.
         if plan_image_type:
             plan_images = self.combined_objs(f'{plan_image_type}_images')
+            plan_structure_sets = self.combined_objs(
+                    f'{plan_image_type}_structure_sets')
         else:
             plan_images = None
+            plan_structure_sets = None
         if treatment_image_type:
             treatment_images = self.combined_objs(
                     f'{treatment_image_type}_images')
         else:
             treatment_images = None
 
+        # Store number of ROIs outlined on planning scan.
+        if plan_structure_sets:
+            info['plan_image_rois'] = len(plan_structure_sets[0].get_rois())
+        else:
+            info['plan_image_rois'] = None
+
         # Store time of image used for plan creation.
         if plan_images:
             info['plan_image_time'] = plan_images[0].get_pandas_timestamp()
@@ -1516,6 +1533,14 @@ class Patient(skrt.core.PathData):
                 info = {}
                 info['id'] = self.id
                 info['modality'] = image_type
+                info['dx'], info['dy'], info['dz'] = image.get_size()
+                info['nx'], info['ny'], info['nz'] = image.get_n_voxels()
+                info['voxel_dx'], info['voxel_dy'], info['voxel_dz'] = (
+                        image.get_voxel_size())
+                ds = image.get_dicom_dataset()
+                info['machine_manufacturer'] = ds.Manufacturer
+                info['machine_model'] = ds.ManufacturerModelName
+                info['station_name'] = getattr(ds, "StationName", None)
                 info['timestamp'] = image.get_pandas_timestamp()
                 info['day'] = None
                 info['hour_in_day'] = None
